pub trait ServiceSpec {
type Config: ?Sized;
type Service: ?Sized;
}Expand description
Type-level description of one pluggable service family.
A service specification gives a registry one type parameter that carries the configuration type accepted by providers and the service contract implemented by produced services.